/*!
 * Pseudo Select v1.0.3
 * Copyright 2018-2019 Isman Fromes
 * Licensed under MIT (http://opensource.org/licenses/MIT)
 */


(function ($) {

    var $body = $('body');

    $.fn.pseudoSelect = function (options) {

        var self = this;

        this.addClass('pseudo-select-list');

        // creating wrapping container around list
        self.wrap('<div class="pseudo-select"></div>');
        var $pseudoSelect = self.parent('.pseudo-select');

        // retrieving Button Text stored in data + adding button to wrapper

        self.children('li:first-child').addClass('active');

        if (!self.children('li.active').eq(0)) {
            var buttonText = self.children('li.active').text();
        }
        else {
            var buttonText = self.data('btn-text');
        }
        $pseudoSelect.prepend('<button class="toggle-button button">' + buttonText + '</button>');

        // saving btn text to first element
        self.children('li:first-child').data('btnText', buttonText);

        // checking for parameters
        if (options) {
            if (options.breaking) {

                // checking if Breaking Point has been reached and add class accordingly
                breakingPointCheck();

                function breakingPointCheck() {
                    $(window).resize(function () {
                        var responsive_viewport = window.innerWidth;
                        if (responsive_viewport > options.breaking) {
                            $pseudoSelect.addClass('break');
                            $pseudoSelect.children('ul').css('top', '');
                        }
                        else {
                            $pseudoSelect.removeClass('break');
                            $pseudoSelect.removeClass('active');
                        }
                    });

                    $(window).trigger('resize');
                }
            }

            if (options.closeOnValueSelected) {
                var listItem = self.children('li');

                // no toggling on menu when the break point has been reached
                listItem.on('click', function (e) {
                    if (!self.parent().hasClass('break')) {
                        toggleDropdown(self);
                    }
                });
            }

            if (options.hasCheckbox) {
                self.addClass('checkbox');
                var listItem = self.children('li');

                // no toggling on menu when the break point has been reached
                listItem.prepend('<span></span>');
            }
        }
    };


    // toggling the ul Menu
    $body.on('click', '.pseudo-select .toggle-button', function () {
        var el = $(this);
        if (!el.parent().hasClass('active')) {
            $('.pseudo-select').removeClass('active');
        }
        toggleDropdown(el);
    });

    function toggleDropdown(el) {
        var btnHeight = $('.toggle-button').outerHeight(true);
        el.parent().toggleClass('active');

        if (el.parent().hasClass('active')) {
            el.parent().children('ul').css('top', btnHeight);
        }
        else {
            el.parent().children('ul').css('top', btnHeight - 10);
        }
    }

    // activating clicked list item
    $body.on('click', '.pseudo-select-list li', function (e) {
        e.preventDefault();

        $(this).parent().children('li').removeClass('active');
        $(this).addClass('active');

        var $button               = $(this).parents('.pseudo-select').children('.button');
        var firstListElementText  = $(this).parent().children('li:first-child').text();
        var activeListElementText = $(this).text();

        // retrieving btn text previously saved
        var btnStartinText = $(this).parents().children('li').data('btn-text');

        if (activeListElementText !== firstListElementText) {
            $button.text(activeListElementText);
        }
        else {
            $button.text(btnStartinText);
        }
    });

}(jQuery));

